pub struct OSLogStore { /* private fields */ }Expand description
Safe wrapper around OSLogStore.
Implementations
Sourceimpl OSLogStore
impl OSLogStore
Sourcepub fn new(scope: OSLogStoreScope) -> Result<Self, LogError>
pub fn new(scope: OSLogStoreScope) -> Result<Self, LogError>
Sourcepub fn from_url(path: impl AsRef<Path>) -> Result<Self, LogError>
pub fn from_url(path: impl AsRef<Path>) -> Result<Self, LogError>
Opens a logarchive URL.
Errors
Returns an error if the path contains a NUL byte or the store cannot be opened.
pub fn position_at(&self, time: SystemTime) -> OSLogPosition
pub fn position_time_interval_since_end( &self, duration: Duration, ) -> OSLogPosition
pub fn position_time_interval_since_latest_boot( &self, duration: Duration, ) -> OSLogPosition
Sourcepub fn get_entries(
&self,
options: OSLogEnumeratorOptions,
position: Option<&OSLogPosition>,
predicate: Option<&str>,
) -> Result<Vec<OSLogStoreEntry>, LogError>
pub fn get_entries( &self, options: OSLogEnumeratorOptions, position: Option<&OSLogPosition>, predicate: Option<&str>, ) -> Result<Vec<OSLogStoreEntry>, LogError>
Enumerates entries from the store.
Errors
Returns an error if the predicate contains a NUL byte or the store enumeration fails.
Sourcepub fn entries(
&self,
options: OSLogEnumeratorOptions,
position: Option<&OSLogPosition>,
predicate: Option<&str>,
) -> Result<Vec<OSLogStoreEntry>, LogError>
pub fn entries( &self, options: OSLogEnumeratorOptions, position: Option<&OSLogPosition>, predicate: Option<&str>, ) -> Result<Vec<OSLogStoreEntry>, LogError>