OSActivity

Struct OSActivity 

pub struct OSActivity { /* private fields */ }
Safe wrapper around os_activity_t.

Implementations

Source

impl OSActivity

pub fn new( description: &str, parent: Option<&OSActivity>, flags: OSActivityFlags, ) -> Result<Self, LogError>

Creates a new activity.

Errors

Returns an error if the description contains a NUL byte or the bridge fails.

pub fn start( description: &str, flags: OSActivityFlags, ) -> Result<Self, LogError>

Creates a deprecated started activity.

Errors

Returns an error if the description contains a NUL byte or the bridge fails.

pub fn current() -> Self

pub fn none() -> Self

pub fn identifiers(&self) -> ActivityIds

pub fn identifier(&self) -> u64

pub fn apply<F>(&self, closure: F)
where F: FnOnce(),

pub fn enter(&self) -> Result<OSActivityScope, LogError>

Enters the activity for the current scope.

Errors

Returns an error if the bridge cannot allocate scope state.

pub fn end(&self)

pub fn label_user_action(label: &str)

pub fn set_breadcrumb(name: &str)